"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
var index_1 = require("./format/index");
/**
 * Sometimes called 'hdrmod' and 'overrides' for various sigplot.Plot() methods,
 * in each case, these are just BlueFile Header interface elements for either
 * type 1000, 2000, etc. signals.
 *
 * See SigPlot for more information.
 * @preferred
 */
var BlueHeaderOptions = /** @class */ (function () {
    /**
     * @param type - The numeric type (1000, 2000)
     * @param formatSize - The size of the data values (int8, etc.)
     * @param formatType - Ordering of the data (x, x+y, x+y+z, etc.)
     * @param xAxis - Data settings for the X axis
     * @param yAxis - Data settings for the Y axis
     * @param subsize - The subsize of the data (matrices, etc.)
     * @param timecode - The time code associated with the data.
     */
    function BlueHeaderOptions(type, formatSize, formatType, xAxis, yAxis, subsize, timecode) {
        if (yAxis === void 0) { yAxis = {}; }
        this.type = type;
        this._formatSize = formatSize;
        this._formatType = formatType;
        this.xstart = xAxis.start;
        this.xdelta = xAxis.delta;
        this.xunits = xAxis.units;
        this.ystart = yAxis.start;
        this.ydelta = yAxis.delta;
        this.yunits = yAxis.units;
        this.subsize = subsize;
        this.timecode = timecode;
    }
    Object.defineProperty(BlueHeaderOptions.prototype, "class", {
        get: function () { return this.type / 1000; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BlueHeaderOptions.prototype, "format", {
        get: function () { return index_1.format(this._formatSize, this._formatType); },
        enumerable: true,
        configurable: true
    });
    /** 1-D Data, like raw signal data */
    BlueHeaderOptions.type1000 = function (formatSize, formatType, xAxis, timecode) {
        // ---------------------------------- //
        var bho = new BlueHeaderOptions(1000, formatSize, formatType, xAxis, undefined, undefined, timecode);
        return JSON.parse(JSON.stringify(bho));
    };
    /** 2-D Data, like falling rasters, etc. */
    BlueHeaderOptions.type2000 = function (formatSize, formatType, xAxis, yAxis, subsize, timecode) {
        // ---------------------------------- //
        var bho = new BlueHeaderOptions(2000, formatSize, formatType, xAxis, yAxis, subsize, timecode);
        return JSON.parse(JSON.stringify(bho));
    };
    return BlueHeaderOptions;
}());
exports.BlueHeaderOptions = BlueHeaderOptions;
//# sourceMappingURL=blue-header-options.js.map