"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * Note: BlueHeader Format (Size and Type) String representation
 */
var format_size_enum_1 = require("./format-size.enum");
var format_type_enum_1 = require("./format-type.enum");
/**
 * Returns the stringified diagraph of the data format size and type as
 * described by Midas BlueFile Format.  This implementation is deliberately
 * incomplete at this time with respect to data types given support in JS.
 *
 * @param size - Enumeration of the data size (shape)
 * @param type - Enumeration of the data type (the size of the data item)
 * @return The stringified diagraph, like 'SF' for scalar float 32.
 * @preferred
 */
function format(size, type) {
    var s = '';
    switch (size) {
        case format_size_enum_1.FormatSize.Scalar:
            s += 'S';
            break;
        case format_size_enum_1.FormatSize.Complex:
            s += 'C';
            break;
        case format_size_enum_1.FormatSize.Vector:
            s += 'V';
            break;
        case format_size_enum_1.FormatSize.Quad:
            s += 'Q';
            break;
        case format_size_enum_1.FormatSize.Matrix:
            s += 'M';
            break;
        case format_size_enum_1.FormatSize.Transform:
            s += 'T';
            break;
        default:
            break;
    }
    switch (type) {
        case format_type_enum_1.FormatType.Int8:
            s += 'B';
            break;
        case format_type_enum_1.FormatType.Int16:
            s += 'I';
            break;
        case format_type_enum_1.FormatType.Int32:
            s += 'L';
            break;
        case format_type_enum_1.FormatType.Int64:
            s += 'X';
            break;
        case format_type_enum_1.FormatType.Float32:
            s += 'F';
            break;
        case format_type_enum_1.FormatType.Float64:
            s += 'D';
            break;
        default:
            break;
    }
    return s;
}
exports.format = format;
//# sourceMappingURL=format.js.map