/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
import { FormatSize, FormatType } from './format/index';
import { Units } from '../m/index';
import { IBlueHeaderOptions } from './bluefile';
import { AxisData } from './axis-data';
/**
 * Sometimes called 'hdrmod' and 'overrides' for various sigplot.Plot() methods,
 * in each case, these are just BlueFile Header interface elements for either
 * type 1000, 2000, etc. signals.
 *
 * See SigPlot for more information.
 * @preferred
 */
export declare class BlueHeaderOptions implements IBlueHeaderOptions {
    version: string;
    type: number;
    readonly class: number;
    readonly format: string;
    timecode: number;
    xstart: number;
    xdelta: number;
    xunits: Units;
    ystart: number;
    ydelta: number;
    yunits: Units;
    /** Controls the size of the ArrayBuffer (default is 1 Mbyte) */
    pipesize: number;
    subsize: number;
    private _formatSize;
    private _formatType;
    /** 1-D Data, like raw signal data */
    static type1000(formatSize: FormatSize, formatType: FormatType, xAxis: AxisData, timecode?: number): IBlueHeaderOptions;
    /** 2-D Data, like falling rasters, etc. */
    static type2000(formatSize: FormatSize, formatType: FormatType, xAxis: AxisData, yAxis: AxisData, subsize?: number, timecode?: number): IBlueHeaderOptions;
    /**
     * @param type - The numeric type (1000, 2000)
     * @param formatSize - The size of the data values (int8, etc.)
     * @param formatType - Ordering of the data (x, x+y, x+y+z, etc.)
     * @param xAxis - Data settings for the X axis
     * @param yAxis - Data settings for the Y axis
     * @param subsize - The subsize of the data (matrices, etc.)
     * @param timecode - The time code associated with the data.
     */
    constructor(type: number, formatSize: FormatSize, formatType: FormatType, xAxis: AxisData, yAxis?: AxisData, subsize?: number, timecode?: number);
}
