/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 */
import { format } from './format/index';
/**
 * Sometimes called 'hdrmod' and 'overrides' for various sigplot.Plot() methods,
 * in each case, these are just BlueFile Header interface elements for either
 * type 1000, 2000, etc. signals.
 *
 * See SigPlot for more information.
 * @preferred
 */
export class BlueHeaderOptions {
    get class() { return this.type / 1000; }
    get format() { return format(this._formatSize, this._formatType); }
    /** 1-D Data, like raw signal data */
    static type1000(formatSize, formatType, xAxis, timecode) {
        // ---------------------------------- //
        const bho = new BlueHeaderOptions(1000, formatSize, formatType, xAxis, undefined, undefined, timecode);
        return JSON.parse(JSON.stringify(bho));
    }
    /** 2-D Data, like falling rasters, etc. */
    static type2000(formatSize, formatType, xAxis, yAxis, subsize, timecode) {
        // ---------------------------------- //
        const bho = new BlueHeaderOptions(2000, formatSize, formatType, xAxis, yAxis, subsize, timecode);
        return JSON.parse(JSON.stringify(bho));
    }
    /**
     * @param type - The numeric type (1000, 2000)
     * @param formatSize - The size of the data values (int8, etc.)
     * @param formatType - Ordering of the data (x, x+y, x+y+z, etc.)
     * @param xAxis - Data settings for the X axis
     * @param yAxis - Data settings for the Y axis
     * @param subsize - The subsize of the data (matrices, etc.)
     * @param timecode - The time code associated with the data.
     */
    constructor(type, formatSize, formatType, xAxis, yAxis = {}, subsize, timecode) {
        this.type = type;
        this._formatSize = formatSize;
        this._formatType = formatType;
        this.xstart = xAxis.start;
        this.xdelta = xAxis.delta;
        this.xunits = xAxis.units;
        this.ystart = yAxis.start;
        this.ydelta = yAxis.delta;
        this.yunits = yAxis.units;
        this.subsize = subsize;
        this.timecode = timecode;
    }
}
//# sourceMappingURL=blue-header-options.js.map