/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * (Abstract) Base Plot class to encourage a unified API going forward.
 */
import * as sigplot from 'sigplot';
import { ConstructorOptions } from './constructor-options';
/**
 * BasePlot is an abstract base class for sigplot.Plot to help unify some of the
 * API for downstream classes.
 *
 */
export class BasePlot {
    /**
     * The settings related to the current plot. For use with checkSettings.
     */
    get settings() {
        return this._options;
    }
    /**
     * If your ConstructorOptions use the default xlabel and ylabel, changing
     * these values will update the X and Y labels by getting the string name
     * of the enumeration (Units).
     */
    set xlab(units) { this._options.xlab = units; }
    set ylab(units) { this._options.ylab = units; }
    /**
     * @param el - The DOM element to draw within (div, etc.)
     * @param options - The ConstructorOptions for this plot.
     */
    constructor(el, options = new ConstructorOptions()) {
        this._plot = new sigplot.Plot(el, options.toInterface());
        this._options = options;
    }
    /**
     * If you resize the DOM element for the plot, call this to cause the plot
     * to redraw
     */
    checkResize() { this._plot.checkresize(); }
    /**
     * Push any changes in the settings to the underlying plot instance.
     */
    checkSettings() { this._plot.change_settings(this.settings.toInterface()); }
}
//# sourceMappingURL=base-plot.js.map