import { SettingsOptions } from './settings-options';
import { Units } from '../m/index';
/**
 * A helper class that implements enumerated interfaces where possible, etc.
 * which makes it not compatible with the IConstructorOptions interface.
 * Use the interface() method to get that interface.
 * @preferred
 */
export class ConstructorOptions extends SettingsOptions {
    /** 'xi' stands for invert fg and bg defined in 'colors' */
    set xi(b) { this.invert = b; }
    get xi() { return this.invert; }
    set nogrid(b) { this.grid = !b; }
    get nogrid() { return !this.grid; }
    set nopan(b) { this.pan = !b; }
    get nopan() { return !this.pan; }
    set nospecs(b) { this.specs = !b; }
    get nospecs() { return !this.specs; }
    set noxaxis(b) { this.show_x_axis = !b; }
    get noxaxis() { return !this.show_x_axis; }
    set noyaxis(b) { this.show_y_axis = !b; }
    get noyaxis() { return !this.show_y_axis; }
    set noreadout(b) { this.show_readout = !b; }
    get noreadout() { return !this.show_readout; }
    set smoothing(b) { this.rasterSmoothing = b; }
    get smoothing() { return this.rasterSmoothing; }
    constructor() {
        super();
        this.xlab = Units.Time;
        this.ylab = Units.Amplitude;
        this.xlabel = () => Units[this.xlab];
        this.ylabel = () => Units[this.ylab];
    }
    /**
     * Export the settings as an IConstructorOptions interface
     */
    toInterface() {
        let o = super.toInterface();
        // Copy in the remaining interface elements.
        o.no_legend_button = this.no_legend_button;
        o.nodragdrop = this.nodragdrop;
        o.scroll_time_interval = this.scroll_time_interval;
        o.x_scrollbar_location = this.x_scrollbar_location;
        o.xlab = this.xlab;
        o.xlabel = this.xlabel;
        o.xdiv = this.xdiv;
        o.ylab = this.ylab;
        o.ylabel = this.ylabel;
        o.ydiv = this.ydiv;
        o.nsec = this.nsec;
        o.anno_type = this.anno_type;
        o.ncolors = this.ncolors;
        o.xi = this.xi;
        o.always_show_marker = this.always_show_marker;
        o.autohide_readout = this.autohide_readout;
        o.autohide_panbars = this.autohide_panbars;
        o.expand = this.expand;
        o.origin = this.origin;
        o.bufmax = this.bufmax;
        o.nokeypress = this.nokeypress;
        o.hide_note = this.hide_note;
        o.font_family = this.font_family;
        o.nogrid = this.nogrid;
        o.nopan = this.nopan;
        o.nospecs = this.nospecs;
        o.noxaxis = this.noxaxis;
        o.noyaxis = this.noyaxis;
        o.noreadout = this.noreadout;
        o.smoothing = this.smoothing;
        // Strip undefined members, re-set the x|ylabel ones.
        o = JSON.parse(JSON.stringify(o));
        o.xlabel = () => Units[this.xlab];
        o.ylabel = () => Units[this.ylab];
        return o;
    }
}
//# sourceMappingURL=constructor-options.js.map