import { CMode, DrawMode, PHUnits, RubberboxAction, RubberboxMode, XCNT } from './enums/index';
/**
 * SettingsOptions are the runtime settings used in SigPlot's top-level Plot.
 *
 * While largely similar to the ISettingsOptions interface, this class uses the
 * enumerations in SigPlot-TS to avoid, "magic numbers," and related issues.
 * @preferred
 */
export class SettingsOptions {
    /** Merge two ISettingsOptions -based interfaces together */
    static interfaceMerge(source, dest) {
        for (let k in source) {
            if ((typeof source[k] == 'function') || (typeof dest[k] == 'function')) {
                continue;
            }
            if (['autox', 'autoy', 'autoz', 'autol'].indexOf(k) > -1) {
                dest[k] = source[k];
            }
            else if (k == 'cmode') {
                dest[k] = CMode[source[k]];
            }
            else if (k == 'drawmode') {
                dest[k] = DrawMode[source[k]];
            }
            else if (k == 'phunits') {
                dest[k] = PHUnits[source[k]];
            }
            else if (['rubberbox_mode', 'rightclick_rubberbox_mode'].indexOf(k) > -1) {
                dest[k] = RubberboxMode[source[k]];
            }
            else if (['rubberbox_action', 'rightclick_rubberbox_action'].indexOf(k) > -1) {
                dest[k] = RubberboxAction[source[k]];
            }
            else if (k == 'xcnt') {
                dest[k] = XCNT[source[k]];
            }
            else {
                dest[k] = source[k];
            }
        }
    }
    /** Convert to the ISettingsOptions interface */
    toInterface() {
        let s = {};
        SettingsOptions.interfaceMerge(this, s);
        return JSON.parse(JSON.stringify(s));
    }
    /** Import settings from an ISettingsOptions interface */
    fromInterface(s) {
        SettingsOptions.interfaceMerge(s, this);
    }
}
//# sourceMappingURL=settings-options.js.map