/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * Generic 1D line plot with highlight capabilities, etc.
 */
import { ILayerSettings } from '../../layer/index';
import { IHighlight, Layer1D } from '../../layer1d/index';
import { BasePlot } from '../../plot/index';
import { LinePlotData } from './line-plot-data';
/**
 * The LinePlot is a one-dimensional representation of data, for example
 * sinusoids, PSD, and FFT.  It supports plotting multiple lines at the same
 * time by using unique Data IDs, which become the names in the plot's legend.
 * @preferred
 */
export declare class LinePlot extends BasePlot {
    /** Internal layer mapping */
    private _dataLayers;
    /**
     * Push the data buffer and other information to the plot.
     * @param plotData - buffer and parameters to plot
     */
    push(plotData: LinePlotData): void;
    /**
     * Get the plotting Layer
     *
     * @param dataId - The dataId corresponding to the layer.
     */
    getLayer(dataId?: string): Layer1D;
    /**
     * Removes the (data signal) layer corresponding to the dataId from the plot
     *
     * @param dataId - The data signal ID corresponding to the layer.
     */
    removeLayer(dataId?: string): void;
    /**
     * This is a simple way to mess with color, opacity, etc. while a plot is
     * instantiated.
     *
     * That said: use with caution!  You can incidentally override various
     * settings that may have really awful effects in SigPlot.
     *
     * @param settings - The settings to change in the layer
     * @param dataId - The data signal ID corresponding to the layer
     */
    changeLayerSettings(settings: ILayerSettings, dataId?: string): void;
    /**
     * Add a highlight to the dataId's plot
     * @param highlight - The highlight to apply.
     * @param dataId - The data signal ID corresponding to the layer.
     */
    addHighlight(highlight: IHighlight, dataId?: string): void;
    /**
     * Remove a highlight from dataId's plot
     * @param highlight - The highlight to apply.
     * @param dataId - The data signal ID corresponding to the layer.
     */
    removeHighlight(highlight: IHighlight, dataId?: string): void;
    /**
     * Clear all highlights for a given dataId
     * @param dataId - The data signal ID corresponding to the layer.
     */
    clearHighlights(dataId?: string): void;
    /**
     * Get the Layer ID for the data ID.  If it doesn't exist, create one using
     * the provided header options.
     *
     * @param dataId - Data (signal) ID whose layer to fetch from the map
     * @param options - header options
     * @return The data layer for the SigPlot layer
     */
    private dataLayer(dataId?, options?, frameSize?);
}
