"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("../../plot/index");
var index_2 = require("../../bluefile/index");
var DEFAULT_SIGNAL = 'signal';
/**
 * The LinePlot is a one-dimensional representation of data, for example
 * sinusoids, PSD, and FFT.  It supports plotting multiple lines at the same
 * time by using unique Data IDs, which become the names in the plot's legend.
 * @preferred
 */
var LinePlot = /** @class */ (function (_super) {
    __extends(LinePlot, _super);
    function LinePlot() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        /** Internal layer mapping */
        _this._dataLayers = {};
        return _this;
    }
    /**
     * Push the data buffer and other information to the plot.
     * @param plotData - buffer and parameters to plot
     */
    LinePlot.prototype.push = function (plotData) {
        if (plotData.dataId === undefined) {
            plotData.dataId = DEFAULT_SIGNAL;
        }
        var options = index_2.BlueHeaderOptions.type1000(plotData.dataSize, plotData.dataType, plotData.xAxis);
        var dl = this.dataLayer(plotData.dataId, options, plotData.buffer.length);
        // If settings are provided, apply them.
        if (plotData.layerSettings !== undefined) {
            this.changeLayerSettings(plotData.layerSettings, plotData.dataId);
        }
        // TODO: sync and/or rsync?
        this._plot.push(dl.layerNumber, plotData.buffer, options);
    };
    /**
     * Get the plotting Layer
     *
     * @param dataId - The dataId corresponding to the layer.
     */
    LinePlot.prototype.getLayer = function (dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        return this._plot.get_layer(this.dataLayer(dataId).layerNumber);
    };
    /**
     * Removes the (data signal) layer corresponding to the dataId from the plot
     *
     * @param dataId - The data signal ID corresponding to the layer.
     */
    LinePlot.prototype.removeLayer = function (dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        this._plot.remove_layer(this.dataLayer(dataId).layerNumber);
    };
    /**
     * This is a simple way to mess with color, opacity, etc. while a plot is
     * instantiated.
     *
     * That said: use with caution!  You can incidentally override various
     * settings that may have really awful effects in SigPlot.
     *
     * @param settings - The settings to change in the layer
     * @param dataId - The data signal ID corresponding to the layer
     */
    LinePlot.prototype.changeLayerSettings = function (settings, dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        var layer = this.getLayer(dataId);
        if (layer !== null) {
            for (var k in settings) {
                if (settings.hasOwnProperty(k)) {
                    layer[k] = settings[k];
                }
            }
        }
    };
    /**
     * Add a highlight to the dataId's plot
     * @param highlight - The highlight to apply.
     * @param dataId - The data signal ID corresponding to the layer.
     */
    LinePlot.prototype.addHighlight = function (highlight, dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        var l = this.getLayer(dataId);
        if (l !== null) {
            l.add_highlight(highlight);
        }
    };
    /**
     * Remove a highlight from dataId's plot
     * @param highlight - The highlight to apply.
     * @param dataId - The data signal ID corresponding to the layer.
     */
    LinePlot.prototype.removeHighlight = function (highlight, dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        var l = this.getLayer(dataId);
        if (l !== null) {
            l.remove_highlight(highlight);
        }
    };
    /**
     * Clear all highlights for a given dataId
     * @param dataId - The data signal ID corresponding to the layer.
     */
    LinePlot.prototype.clearHighlights = function (dataId) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        var l = this.getLayer(dataId);
        if (l !== null) {
            l.clear_highlights();
        }
    };
    /**
     * Get the Layer ID for the data ID.  If it doesn't exist, create one using
     * the provided header options.
     *
     * @param dataId - Data (signal) ID whose layer to fetch from the map
     * @param options - header options
     * @return The data layer for the SigPlot layer
     */
    LinePlot.prototype.dataLayer = function (dataId, options, frameSize) {
        if (dataId === void 0) { dataId = DEFAULT_SIGNAL; }
        var val;
        if (this._dataLayers[dataId] !== undefined) {
            val = this._dataLayers[dataId];
            // Resize if the length of data changed.
            if (val.frameSize !== frameSize && frameSize !== undefined) {
                var l = this.getLayer(dataId);
                if (l !== null) {
                    l.change_settings({ framesize: frameSize });
                }
                val.frameSize = frameSize;
            }
        }
        else {
            // Setting the 'name' layer option identifies it on the legend
            // if visible.  Setting the framesize gives us an initial pipe size.
            val = {
                frameSize: frameSize,
                layerNumber: this._plot.overlay_pipe(options, { framesize: frameSize, name: dataId })
            };
            this._dataLayers[dataId] = val;
        }
        return val;
    };
    return LinePlot;
}(index_1.BasePlot));
exports.LinePlot = LinePlot;
//# sourceMappingURL=line-plot.js.map