/**
 * Author:  Thomas Goodwin
 * Company: Geon Technologies, LLC
 *
 * Purpose: Constructor Options helper Class
 */
import { IConstructorOptions } from './sigplot';
import { SettingsOptions } from './settings-options';
import { Origin } from './enums/index';
import { Units } from '../m/index';
/**
 * A helper class that implements enumerated interfaces where possible, etc.
 * which makes it not compatible with the IConstructorOptions interface.
 * Use the interface() method to get that interface.
 * @preferred
 */
export declare class ConstructorOptions extends SettingsOptions {
    no_legend_button: boolean;
    nodragdrop: boolean;
    scroll_time_interval: number;
    x_scrollbar_location: any;
    xlab: Units;
    xlabel: string | ((...args: any[]) => string);
    xdiv: number;
    ylab: Units;
    ylabel: string | ((...args: any[]) => string);
    ydiv: number;
    nsec: number;
    anno_type: number;
    /** Number of colors to draw (default is 16) */
    ncolors: number;
    always_show_marker: boolean;
    autohide_readout: boolean;
    autohide_panbars: boolean;
    /**
     * Combined with 'all' = true will cause y-axis to expand automatically to
     * show all data.
     */
    expand: boolean;
    origin: Origin;
    bufmax: number;
    nokeypress: boolean;
    hide_note: boolean;
    font_family: string;
    /** 'xi' stands for invert fg and bg defined in 'colors' */
    xi: boolean;
    nogrid: boolean;
    nopan: boolean;
    nospecs: boolean;
    noxaxis: boolean;
    noyaxis: boolean;
    noreadout: boolean;
    smoothing: boolean;
    constructor();
    /**
     * Export the settings as an IConstructorOptions interface
     */
    toInterface(): IConstructorOptions;
}
