"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("./enums/index");
/**
 * SettingsOptions are the runtime settings used in SigPlot's top-level Plot.
 *
 * While largely similar to the ISettingsOptions interface, this class uses the
 * enumerations in SigPlot-TS to avoid, "magic numbers," and related issues.
 * @preferred
 */
var SettingsOptions = /** @class */ (function () {
    function SettingsOptions() {
    }
    /** Merge two ISettingsOptions -based interfaces together */
    SettingsOptions.interfaceMerge = function (source, dest) {
        for (var k in source) {
            if ((typeof source[k] == 'function') || (typeof dest[k] == 'function')) {
                continue;
            }
            if (['autox', 'autoy', 'autoz', 'autol'].indexOf(k) > -1) {
                dest[k] = source[k];
            }
            else if (k == 'cmode') {
                dest[k] = index_1.CMode[source[k]];
            }
            else if (k == 'drawmode') {
                dest[k] = index_1.DrawMode[source[k]];
            }
            else if (k == 'phunits') {
                dest[k] = index_1.PHUnits[source[k]];
            }
            else if (['rubberbox_mode', 'rightclick_rubberbox_mode'].indexOf(k) > -1) {
                dest[k] = index_1.RubberboxMode[source[k]];
            }
            else if (['rubberbox_action', 'rightclick_rubberbox_action'].indexOf(k) > -1) {
                dest[k] = index_1.RubberboxAction[source[k]];
            }
            else if (k == 'xcnt') {
                dest[k] = index_1.XCNT[source[k]];
            }
            else {
                dest[k] = source[k];
            }
        }
    };
    /** Convert to the ISettingsOptions interface */
    SettingsOptions.prototype.toInterface = function () {
        var s = {};
        SettingsOptions.interfaceMerge(this, s);
        return JSON.parse(JSON.stringify(s));
    };
    /** Import settings from an ISettingsOptions interface */
    SettingsOptions.prototype.fromInterface = function (s) {
        SettingsOptions.interfaceMerge(s, this);
    };
    return SettingsOptions;
}());
exports.SettingsOptions = SettingsOptions;
//# sourceMappingURL=settings-options.js.map