import * as sigplot from 'sigplot';
import { Boxes2Options } from './boxes2-options';
import { Box } from './box';
/**
 * This is an alternate Boxes plugin that allows control over
 * which sides of the box to draw.
 *
 * This class mirrors closely the version found in SigPlot.
 * However more methods have been added for supporting
 * updating, etc. as well as drawing partial boxes.
 */
export declare class Boxes2Plugin {
    options: Boxes2Options;
    /** Minimum X position */
    readonly minX: number;
    /** Maximum X position */
    readonly maxX: number;
    /** Minimum Y position */
    readonly minY: number;
    /** Maximum Y Position */
    readonly maxY: number;
    /** Map of the boxes to draw */
    private boxes;
    /** The plot to draw within */
    private plot;
    /** Minimum X position */
    private _minX;
    /** Maximum X position */
    private _maxX;
    /** Minimum Y position */
    private _minY;
    /** Maximum Y Position */
    private _maxY;
    constructor(options?: Boxes2Options);
    /**
     * Initialize the plugin for the plot
     * @param plot
     */
    init(plot: sigplot.Plot): void;
    /**
     * Menu callback
     */
    menu(): any;
    /**
     * Add a box to the view
     * @param id The unique ID for the box
     * @param box The box parameters to draw
     * @param redraw Whether or not to redraw with this call
     */
    add_box(id: string, box: Box, redraw?: boolean): void;
    /**
     * Update a box in the view
     * @param id The unique ID for the box
     * @param box The box parameters to draw
     * @param redraw Whether or not to redraw with this call
     */
    update_box(id: string, box: Box, redraw?: boolean): void;
    /**
     * Remove a box from the view
     * @param id The unique ID for the box
     * @param redraw Whether or not to redraw with this call
     */
    remove_box(id: string, redraw?: boolean): void;
    /**
     * Clears all boxes
     * @param redraw Whether or not to redraw with this call
     */
    clear_boxes(redraw?: boolean): void;
    /**
     * Refresh all the drawn blocks
     * @param canvas
     */
    refresh(canvas: HTMLCanvasElement): void;
    dispose(): void;
    private resetStats();
}
